@@ -147,12 +147,16 @@ def monitored_channel(channel, monitored_channels):
 
 
 def construct_alert(frm, channel, msg, elapsed=None):
+    global the_printer
     alert_title = frm + "@" + channel + ":"
     message = msg
     if elapsed:
         message += " (" + str(round(seconds_listen_channel - elapsed)) + "s left)"
-    return trim_leading_dashes(alert_title), trim_leading_dashes(message)
-
+    if debug:
+        the_printer("",message)
+    message = trim_leading_dashes(message)
+    alert = trim_leading_dashes(alert_title)
+    return alert, message
 
 def get_elapsed_time_on_channel(channel, monitored_channels):
     last_chatted = monitored_channels[channel]
